DAGparameters takes a DAG and augments it with parameters.
For binary data these are the parameters of the posterior beta
distributions and its mean. For continuous data, these are parameters
of the posterior distributions of the edge coefficients from arXiv:2010.00684.
There is support for user-defined augmentation, with the caveat that it
must match the output format of either the binary or continuous cases.